==> haskell-hspec-smallcheck-0.5.3-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-KDM1FpbN3PdGBF9BRGFjoS
key:                  hspec-smallcheck-0.5.3-KDM1FpbN3PdGBF9BRGFjoS
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  86cde82825a6a2216f67c07b81f05ea9
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-KDM1FpbN3PdGBF9BRGFjoS
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hspec-core-2.10.9-A0393VK8GizATPB42jhNhE
    smallcheck-1.2.1.1-ASrUfqawm0F5YP30bcAd6u

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.3-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-6uq0lnMYsdN1q7sWIBEanp
key:                  hspec-smallcheck-0.5.3-6uq0lnMYsdN1q7sWIBEanp
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  2981c5efd7b8545ca8af409091606503
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-6uq0lnMYsdN1q7sWIBEanp
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hspec-core-2.10.9-GDNOEug74Za8kCbopvThyV
    smallcheck-1.2.1.1-4dP20mJsU9E9RyQO8YSljr

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
